checks

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetAllCheckRegistrations added in v0.5.0

func GetAllCheckRegistrations(cfg *config.Config) []checker.CheckRegistration

GetAllCheckRegistrations returns all check registrations from all languages. This is useful for listing available checks. Common checks that use source_dir are wrapped so single-check runs (e.g. a2 run common:shutdown) also use multi-path.

func GetChecks

func GetChecks(cfg *config.Config, detected language.DetectionResult) []checker.CheckRegistration

GetChecks returns checks for detected languages based on configuration. Checks are ordered with critical checks first. Language-specific checks are wrapped to use the configured source_dir.

func GetSuggestions added in v0.5.0

func GetSuggestions(cfg *config.Config) map[string]string

GetSuggestions returns a map of check ID to suggestion string. This aggregates suggestions from all language check registrations.

Types

This section is empty.

Directories

Path Synopsis
Package nodecheck provides code quality checks for Node.js projects.
Package nodecheck provides code quality checks for Node.js projects.
Package security provides safety/security checks for detecting potential malicious code patterns including shell injection, file system abuse, network exfiltration, and code obfuscation.
Package security provides safety/security checks for detecting potential malicious code patterns including shell injection, file system abuse, network exfiltration, and code obfuscation.
Package typescriptcheck provides code quality checks for TypeScript projects.
Package typescriptcheck provides code quality checks for TypeScript projects.

Jump to