Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAllCheckRegistrations ¶ added in v0.5.0
func GetAllCheckRegistrations(cfg *config.Config) []checker.CheckRegistration
GetAllCheckRegistrations returns all check registrations from all languages. This is useful for listing available checks. Common checks that use source_dir are wrapped so single-check runs (e.g. a2 run common:shutdown) also use multi-path.
func GetChecks ¶
func GetChecks(cfg *config.Config, detected language.DetectionResult) []checker.CheckRegistration
GetChecks returns checks for detected languages based on configuration. Checks are ordered with critical checks first. Language-specific checks are wrapped to use the configured source_dir.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package nodecheck provides code quality checks for Node.js projects.
|
Package nodecheck provides code quality checks for Node.js projects. |
|
Package security provides safety/security checks for detecting potential malicious code patterns including shell injection, file system abuse, network exfiltration, and code obfuscation.
|
Package security provides safety/security checks for detecting potential malicious code patterns including shell injection, file system abuse, network exfiltration, and code obfuscation. |
|
Package typescriptcheck provides code quality checks for TypeScript projects.
|
Package typescriptcheck provides code quality checks for TypeScript projects. |
Click to show internal directories.
Click to hide internal directories.