Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BuildCheck ¶
type BuildCheck struct{}
BuildCheck verifies that the project compiles successfully.
func (*BuildCheck) ID ¶
func (c *BuildCheck) ID() string
func (*BuildCheck) Name ¶
func (c *BuildCheck) Name() string
type CoverageCheck ¶
type CoverageCheck struct {
Threshold float64 // Minimum coverage percentage (default 80.0)
}
CoverageCheck verifies that test coverage meets a threshold.
func DefaultCoverageCheck ¶
func DefaultCoverageCheck() *CoverageCheck
DefaultCoverageCheck returns a CoverageCheck with the default 80% threshold.
func (*CoverageCheck) ID ¶
func (c *CoverageCheck) ID() string
func (*CoverageCheck) Name ¶
func (c *CoverageCheck) Name() string
func (*CoverageCheck) SetCoverageThreshold ¶ added in v0.6.4
func (c *CoverageCheck) SetCoverageThreshold(t float64)
type CyclomaticCheck ¶ added in v0.1.2
type CyclomaticCheck struct {
Threshold int // Default: 15
}
CyclomaticCheck measures cyclomatic complexity of Go functions.
func (*CyclomaticCheck) ID ¶ added in v0.1.2
func (c *CyclomaticCheck) ID() string
func (*CyclomaticCheck) Name ¶ added in v0.1.2
func (c *CyclomaticCheck) Name() string
type DeadcodeCheck ¶ added in v0.6.4
type DeadcodeCheck struct{}
DeadcodeCheck detects unreachable code using the deadcode tool.
func (*DeadcodeCheck) ID ¶ added in v0.6.4
func (c *DeadcodeCheck) ID() string
func (*DeadcodeCheck) Name ¶ added in v0.6.4
func (c *DeadcodeCheck) Name() string
type DepsCheck ¶
type DepsCheck struct{}
DepsCheck scans for known vulnerabilities using govulncheck.
type DepsFreshnessCheck ¶ added in v0.6.4
type DepsFreshnessCheck struct{}
DepsFreshnessCheck detects outdated Go module dependencies.
func (*DepsFreshnessCheck) ID ¶ added in v0.6.4
func (c *DepsFreshnessCheck) ID() string
func (*DepsFreshnessCheck) Name ¶ added in v0.6.4
func (c *DepsFreshnessCheck) Name() string
type FormatCheck ¶
type FormatCheck struct{}
FormatCheck verifies that all Go code is properly formatted.
func (*FormatCheck) ID ¶
func (c *FormatCheck) ID() string
func (*FormatCheck) Name ¶
func (c *FormatCheck) Name() string
type FunctionComplexity ¶ added in v0.1.2
FunctionComplexity holds complexity info for a single function.
type LoggingCheck ¶ added in v0.1.2
type LoggingCheck struct{}
LoggingCheck verifies proper logging practices in Go code.
func (*LoggingCheck) ID ¶ added in v0.1.2
func (c *LoggingCheck) ID() string
func (*LoggingCheck) Name ¶ added in v0.1.2
func (c *LoggingCheck) Name() string
type ModuleCheck ¶
type ModuleCheck struct{}
ModuleCheck verifies that go.mod exists and has a valid Go version.
func (*ModuleCheck) ID ¶
func (c *ModuleCheck) ID() string
func (*ModuleCheck) Name ¶
func (c *ModuleCheck) Name() string
type RaceCheck ¶
type RaceCheck struct{}
RaceCheck runs tests with the race detector enabled to find data races.
type TestsCheck ¶
type TestsCheck struct{}
TestsCheck runs go test to verify all tests pass.
func (*TestsCheck) ID ¶
func (c *TestsCheck) ID() string
func (*TestsCheck) Name ¶
func (c *TestsCheck) Name() string