Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BuildCheck ¶
type BuildCheck struct{}
BuildCheck runs swift build to verify the project compiles.
func (*BuildCheck) ID ¶
func (c *BuildCheck) ID() string
func (*BuildCheck) Name ¶
func (c *BuildCheck) Name() string
type CoverageCheck ¶
type CoverageCheck struct {
Threshold float64
}
CoverageCheck verifies test coverage meets the threshold.
func (*CoverageCheck) ID ¶
func (c *CoverageCheck) ID() string
func (*CoverageCheck) Name ¶
func (c *CoverageCheck) Name() string
type DepsCheck ¶
type DepsCheck struct{}
DepsCheck checks for dependency issues in Package.resolved.
type FormatCheck ¶
type FormatCheck struct {
Config *config.SwiftLanguageConfig
}
FormatCheck verifies Swift code is formatted.
func (*FormatCheck) ID ¶
func (c *FormatCheck) ID() string
func (*FormatCheck) Name ¶
func (c *FormatCheck) Name() string
type LintCheck ¶
type LintCheck struct {
Config *config.SwiftLanguageConfig
}
LintCheck runs SwiftLint to check for common mistakes and style issues.
type ProjectCheck ¶
type ProjectCheck struct{}
ProjectCheck verifies that a Swift project exists (Package.swift).
func (*ProjectCheck) ID ¶
func (c *ProjectCheck) ID() string
func (*ProjectCheck) Name ¶
func (c *ProjectCheck) Name() string
type TestsCheck ¶
type TestsCheck struct{}
TestsCheck runs swift test to verify tests pass.
func (*TestsCheck) ID ¶
func (c *TestsCheck) ID() string
func (*TestsCheck) Name ¶
func (c *TestsCheck) Name() string
Click to show internal directories.
Click to hide internal directories.